fnss.topologies.topology.Topology.edges — FNSS 0.7.0 documentation

# fnss.topologies.topology.Topology.edges

`Topology.` `edges`(nbunch=None, data=False, default=None)

  Return a list of edges.

  Edges are returned as tuples with optional data in the order (node, neighbor, data).

  Parameters: | nbunch : iterable container, optional (default= all nodes) A container of nodes. The container will be iterated through once. data : string or bool, optional (default=False) The edge attribute returned in 3-tuple (u,v,ddict[data]). If True, return edge attribute dict in 3-tuple (u,v,ddict). If False, return 2-tuple (u,v). default : value, optional (default=None) Value used for edges that dont have the requested attribute. Only relevant if data is not True or False.
  Returns: | edge_list: list of edge tuples Edges that are adjacent to any node in nbunch, or a list of all edges if nbunch is not specified.

  See also

  `edges_iter`
    return an iterator over the edges

  Notes

  Nodes in nbunch that are not in the graph will be (quietly) ignored. For directed graphs this returns the out-edges.

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_path([0,1,2])
      >>> G.add_edge(2,3,weight=5)
      >>> G.edges()
      [(0, 1), (1, 2), (2, 3)]
      >>> G.edges(data=True) # default edge data is {} (empty dictionary)
      [(0, 1, {}), (1, 2, {}), (2, 3, {'weight': 5})]
      >>> list(G.edges_iter(data='weight', default=1))
      [(0, 1, 1), (1, 2, 1), (2, 3, 5)]
      >>> G.edges([0,3])
      [(0, 1), (3, 2)]
      >>> G.edges(0)
      [(0, 1)]